@@ -63,7 +63,7 @@ $simnetwork @themereports %simtitles %reporttitles %retrievedata
 $target %dowhat 
 );
 
-$VERSION = '0.51.10'; # our $VERSION = '';
+$VERSION = '0.51.11'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT is an optimization and morphing program that can be used with simulation programs receiving text files as input and emitting text files as output. It adopts the block coordinate descent optimization method.';
 
 #################################################################################
@@ -1017,11 +1017,8 @@ sub exe
 sub start
 {
 ###########################################
-say "\nTHIS IS Sim::OPT (version 0.47.16),
-a morphing and optimizazion program.
-
-.  .  .  .  .  .  .  .  .  .  .  .  .
-
+say "\nHi. This is Sim::OPT,
+a morphing and optimizazion program based on problem decomposition.
 Please insert the name of a configuration file for OPT (Unix path)\n";
 ###########################################
 	$configfile = <STDIN>;
@@ -1163,7 +1160,7 @@ Sim::OPT.
 
 =head1 DESCRIPTION
 
-Sim::OPT is an optimization and morphing program that can be used with simulation programs receiving text files as input and emitting text files as output. Some of Sim::OPT's optimization modules (Sim::OPT, Sim::OPT::Descent) pursue optimization by overlapping block coordinate descent (inexact Gauss-Seidel method). Another optimization module (Sim::OPT::Takechange) seeks for the least explored search paths when exploring new search spaces. Sim::OPT's morphing module (Sim::OPT::Morph) manipulates text files recognizing variables by position. The Sim::OPT::Parcoord3d module converts 2D parallel coordinates plots in Autolisp instructions for obtaining 3D plots as Autocad drawings.
+Sim::OPT is an optimization and morphing program that can be used with simulation programs receiving text files as input and emitting text files as output. Some of Sim::OPT's optimization modules (Sim::OPT, Sim::OPT::Descent) pursue optimization by block coordinate descent (i.e. inexact Gauss-Seidel method) with bloks (subspaces) that can overlap. Another optimization module (Sim::OPT::Takechange) seeks for the least explored search paths when exploring new search spaces. Sim::OPT's morphing module (Sim::OPT::Morph) manipulates text files recognizing variables by position. The Sim::OPT::Parcoord3d module converts 2D parallel coordinates plots in Autolisp instructions for obtaining 3D plots as Autocad drawings.
 
 Sim::OPT's morphing and reporting modules contain several additional functions specifically targeting the ESP-r building performance simulation platform. A working knowledge of ESP-r (http://www.esru.strath.ac.uk/Programs/ESP-r.htm) is necessary to use those functionalities.
 
@@ -1185,8 +1182,9 @@ The instance number that has to considered the basic one, corresponding to the r
 
 Where Sim::OPT may be fit for a task? Where a certain exploration is complex and/or when it is to be confronted through decomposition, by dividing a problem in overlapping subproblems; when there aren't slick tools suitable to decomposition-based, simulation-based optimization; when spending a day, or two, or three setting up a model may spare months of work.
 
-Where it may not be suitable for the task? For quick shots at small explorations.
+Where it may not be suitable for the task? Due to the investments which is necessary for getting acquainted with its raw interface, for quick shots at small explorations.
 
+The program works under linux. Instructions that may allow use under windows have been included in the code, but have never been tested.
 
 =head2 EXPORT
 
